=========
djeese-fs
=========

A simple remote file storage system.
Contains a django storage backend and a Twisted based Server.

Server
======

``djeesefs <root_folder> <root_url> <auth_server> <max_bucket_size> <max_file_size> [--port=9000] [--verbose]``
